# Mdk version-release policy

# First: Get versions names right is complicated (tm)
# Second: kernel allways have the version & release number in the name
#         this is done to preserving a working kernel when you install 
#         a new one
# Stored in %rpmrversion & %rpmrelease
#
# We want to reflect in the kernel naming:
#   - vanilla kernel in with is based (ex. 2.4.21) 
#     this version is stored in %realversion
#   - Number of Mandrake kernel based on this vanilla kernel (ex. 2mdk).
#     stored in %mdusepatch.
#    
# That gives us a nice name: 2.4.21.2mdk
# 
# As version and release are allways fixed, name of the package is 
# going to be:
#        kernel-2.4.21.2mdk-1-1mdk
#
# Confused already?
#
# Now there arrive pre/rc kernels.  This kernels have the particularity
# that they have the name of the new kernel, but they are based in the
# tar file of the old kernel, i.e. names are basically:
#  - vanilla kernel: 2.4.21
#  - patch name: 2.4.22-pre3
#    stored in %use_patch
#  - Number of Mandrake kernel based in this pre kernel 2mdk
#
# That gives us a nice name again: 2.4.22.pre3.2mdk
# Problems now are:
#   - sublevel of vanilla kernel 21 (needed for tar file)
#   - sublevel of kernel is 22 (needed for prepatch and naming 
#     the package).
# This explains the need of %tar_version, because this will be different
# of %real_version if there is a pre/rc patch.
# 
# Still with me?
# 
# There are still a problem, when real 2.4.22 cames out, it will have
# a mane like: 
#              2.4.22.1mdk
# this name is (for rpm ordering of versions) smaller than:
#              2.4.22.pre3.2mdk
# to fix that we add a 0 to the name (and appear the need of realrelease)
# in the pre/rc
# 	       2.4.22.0.pre3.2mdk
#
# Take one aspirine.  Relax.
#
# Problem now is that names are just really ugly, and specially
# lilo/grub names are very difficult to read/type.
# Notice that the extra .0 is there only to make visual comparations 
# easy, but it is an annoyance.
#
# Lilo name for this kernel will be:
#       2422-0.pre3.2mdk
# And as everybody knows, putting dot's in lilo names is not nice.
# Then we change the kernel name (for loaders, and directory names only)
# to a more userfriendly:
# 		2.4.22pre3-2mdk
# That way, smp, enterprise versions continue to have the well known names
# in the loader of:
#		2422pre3-2smp
#
# For a non pre/rc kernel define (real examples in brakets)
#     2.4.X.Ymdk [2.4.22.2mdk]
# where
#	%sublvel = X 	[22]
#   	%mdusepatch = Y [2]
#	%use_patch 0	[0]
#
# For a pre/rc kernel do:
#	2.4.X.0.Y.Zmdk [2.4.22.0.pre3.2mdk]
# where
#	%sublvel = X 	[22]
#   	%mdusepatch = Z [2]
#	%use_patch Y	[pre3]
#
# I hope this is all clear now. If you have any doubt, please mail me at:
#
# Juan Quintela <quintela@mandrakesoft.com>

# kernel version:
# kernel branch: ^(.*\..*)\..*
%define level 2.6
# kernel version: ^.*\.\.*\.(.*)
%define sublevel 0
# kernel pre version: ^.*-(.*)
%define usepatch test5

# Then basic kernel version is:
%define kversion %{level}.%{sublevel}

# This is a testing kernel, we do not name it 'kernel'
# but kernel-{branch}
%define kname kernel-%level

# The tar file of the kernel : linux-(.*).tar.bz2
%define tarversion %level.%sublevel-%usepatch

%define preversion 1
%define mdusepatch 1mdk

# binary version-release; always 1 !
%define rpmversion 1
%define rpmrelease 1mdk

# src.rpm version-release
%define realversion %kversion
%if %preversion
    %define realrelease 0.%usepatch.%mdusepatch
%else
    %define realrelease %mdusepatch
%endif

# The interenal kernel version (given by uname)
# note we will add the $flavour like smp, secure...
%define KVERREL %realversion-%realrelease

# Some path
%define _kerneldir /usr/src/linux-%{KVERREL}
%define _bootdir /boot
%define _modulesdir /lib/modules

##################################################
#                                                #
# About kernel config                            #
# put your .config in Source10 (tar.bz2)         #
# should at top                                  #
# each file are called:                          #
# kernel-config-2.6-ARCH$flavour                 #
# $flavour is "" for default, smp, secure, um... #
##################################################


# What do we build ?

# The basic kernel, for normal user ?
%define build_default 1
# The smp kernel ?
%define build_smp 1
# The very secure kernel ?
%define build_secure 0
# For poeple who give money ?
%define build_enterprise 0
# The kernel used to create CD ?
%define build_BOOT 0
# Do we want the doc, but who read the doc ?
%define build_doc 1
# The source, to compil kernel apps ?
%define build_source 1
# The user mode linux ?
%define build_um 0

%ifarch i586
%endif
%ifarch ppc
    %define build_BOOT 0
    %define build_entreprise 0
%endif
%ifarch alpha
    %define build_BOOT 0
    %define build_entreprise 0
%endif
%ifarch sparc
    %define build_BOOT 0
    %define build_entreprise 0
%endif
%ifarch sparc64
    %define build_BOOT 0
    %define build_entreprise 0
%endif
%ifarch x86_64
    %define build_entreprise 0
%endif
%ifarch ia64
    %define build_entreprise 0
%endif

%{?_without_default: %{expand: %%define build_default 0}}
%{?_without_smp: %{expand: %%define build_smp 0}}
%{?_without_secure: %{expand: %%define build_secure 0}}
%{?_without_enterprise: %{expand: %%define build_enterprise 0}}
%{?_without_BOOT: %{expand: %%define build_BOOT 0}}
#%{?_without_minimal: %{expand: %%define build_minimal 0}}
#%{?_without_mydsdt: %{expand: %%define build_mydsdt 0}}
#%{?_without_debug: %{expand: %%define build_debug 0}}
%{?_without_doc: %{expand: %%define build_doc 0}}
%{?_without_source: %{expand: %%define build_source 0}}
%{?_without_um: %{expand: %%define build_um 0}}

%{?_with_default: %{expand: %%define build_default 1}}
%{?_with_smp: %{expand: %%define build_smp 1}}
%{?_with_secure: %{expand: %%define build_secure 1}}
%{?_with_enterprise: %{expand: %%define build_enterprise 1}}
%{?_with_BOOT: %{expand: %%define build_BOOT 1}}
#%{?_with_minimal: %{expand: %%define build_minimal 1}}
#%{?_with_mydsdt: %{expand: %%define build_mydsdt 1}}
#%{?_with_debug: %{expand: %%define build_debug 1}}
#%{?_with_acpi: %{expand: %%define build_acpi 1}}
%{?_with_doc: %{expand: %%define build_doc 1}}
%{?_with_source: %{expand: %%define build_source 1}}
%{?_with_um: %{expand: %%define build_um 1}}

###########################
# End of compilation flag #
###########################


# Source
Source: linux-%tarversion.tar.bz2

#ARCH .config
SOURCE10: kernel-config-%level.tar.bz2

# ac patch
# Patch20: http://www.kernel.org/pub/linux/kernel/people/alan/linux-%level/%tarversion/patch-%tarversion-ac3.bz2
# Supermount patch
#Patch1: http://belnet.dl.sourceforge.net/sourceforge/supermount-ng/supermount-2.0.1-2.5.75.patch.gz
# Rediff over test2
Patch1: http://belnet.dl.sourceforge.net/sourceforge/supermount-ng/supermount-2.0.2-2.6.0-test5.patch.gz

# usermode linux
#Patch10: http://belnet.dl.sourceforge.net/sourceforge/user-mode-linux/uml-patch-2.6.0-test1.bz2
# Rediff
# Patch10: uml-patch-2.6.0-test1.patch.bz2

# Multimedia patch
Patch30: http://members.optusnet.com.au/ckolivas/kernel/2.5/2.6.0-test5/patch-test5-O20int
# Patch31: lmsensors-2.6-test2.patch.bz2
# IDE probe patch
# Patch32: 2.6.0-test2-ata_probe.patch.bz2
#############################
# End of sources and patchs #
#############################

%define globalwarning %kname This kernel is for development and testing ONLY

Name: %kname
Summary: The Linux Kernel
Version: %realversion
Release: %realrelease
License: GPL
Group: System/Kernel and hardware
URL: http://www.kernel.org
BuildRoot: %_tmppath/%{name}-%KVERREL-root
# Don't bother on other arch, it is not ready
ExclusiveArch: i586 ppc
BuildRequires: db3-devel

# %define requires modutils >= 2.4.15-1mdk, mkinitrd >= 3.1.6-24mdk
# %define prereq initscripts >= 6.40.2-44.1mdk
# %define prereq initscripts >= 5.83-4mdk
# %define conflicts kernel-pcmcia-cs <= 2.4.8-26mdk, iptables <= 1.2.4-1mdk
# %define kprovides %kname = %{realversion}
%define requires module-init-tools >= 0.9.11a, mkinitrd >= 3.4.43
%define prereq bootloader-utils
%define kprovides %kname = %{KVERREL}

%description
The kernel package contains the Linux kernel (vmlinuz), the core of your
Mandrake Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.

************** WARNING ************************
This kernel is for development and testing ONLY
Some drivers can be missing and it can completely bork your system.

Take care and don't install this kernel if you are not 
able to repair the system if it no longer boots


%if %build_default
%package -n kernel-%KVERREL
Version: %rpmversion
Release: %rpmrelease
Summary: The Linux kernel (the core of the Linux operating system).
Group: System/Kernel and hardware
# We don't provide kernel itself !!
Provides: %kprovides
Requires: %requires
PreReq:   %prereq

%description -n kernel-%KVERREL
The kernel package contains the Linux kernel (vmlinuz), the core of your
Mandrake Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.

%globalwarning
%endif

%if %build_smp
%package -n kernel-smp-%KVERREL
Version: %rpmversion
Release: %rpmrelease
Group: System/Kernel and hardware
Summary: The Linux Kernel compiled for SMP machines.
Provides: %kprovides
Requires: %requires
PreReq:   %prereq

%description -n kernel-smp-%KVERREL
This package includes a SMP version of the Linux %{realversion} kernel. It is
required only on machines with two or more CPUs, although it should work
fine on single-CPU boxes.

%globalwarning
%endif

%if %build_secure
%package -n kernel-secure-%KVERREL
Version: %rpmversion
Release: %rpmrelease
Summary: The Linux Kernel compiled for SECURE machines.
Group: System/Kernel and hardware
Provides: %kprovides
Requires: %requires
PreReq:   %prereq

%description -n kernel-secure-%KVERREL
This package includes a SECURE version of the Linux %{kversion}
kernel. This package add options for kernel that make it more secure
for servers and such. See :

http://grsecurity.net/features.htm

for list of features we have included.

%globalwarning
%endif

%if %build_enterprise
%package -n kernel-enterprise-%KVERREL
Version: %rpmversion
Release: %rpmrelease
Summary: The Linux Kernel compiled with options for Enterprise server usage.
Group: System/Kernel and hardware
Provides: %kprovides
Requires: %requires
PreReq:   %prereq

%description -n kernel-enterprise-%KVERREL
This package includes a kernel that has appropriate configuration options
enabled for the typical large enterprise server.  This includes SMP support
for multiple processor machines, support for large memory configurations
and other appropriate items.

%globalwarning
%endif

%if %build_BOOT
%package -n kernel-BOOT-%KVERREL
Version: %rpmversion
Release: %rpmrelease
Summary: The version of the Linux kernel used on installation boot disks.
Group: System/Kernel and hardware
Url: https://kenobi.mandrakesoft.com/~chmou/kernel/BOOT/
#Provides: %kprovides
Requires: %requires
PreReq:   %prereq

%description -n kernel-BOOT-%KVERREL
This package includes a trimmed down version of the Linux kernel.
This kernel is used on the installation boot disks only and should not
be used for an installed system, as many features in this kernel are
turned off because of the size constraints.

%globalwarning
%endif

%if %build_um
%package -n kernel-um-%KVERREL
Version: %rpmversion
Release: %rpmrelease
Summary: The usermode %kname.
Group: System/Kernel and hardware
Url: http://user-mode-linux.sourceforge.net/
Provides: usermode-linux = %KVERREL

%description -n kernel-um-%KVERREL
This package contain the usermode linux. It compile the
kernel as a normal application. It permit to run linux under
linux within a virtual compute and start system.
You do not need to be root run it.

%globalwarning
%endif

%if %build_source
%package -n %kname-source
Version: %realversion
Release: %realrelease
Summary: The source code for the Linux kernel.
Group: Development/Kernel

%description -n %kname-source
The kernel-source package contains the source code files for the Linux
kernel. These source files are needed to build most C programs, since
they depend on the constants defined in the source code. The source
files can also be used to build a custom kernel that is better tuned to
your particular hardware, if you are so inclined (and you know what you're
doing).

%globalwarning
%endif

%if %build_doc
%package -n %kname-doc
Version: %realversion
Release: %realrelease
Summary: Various documentation bits found in the kernel source.
Group: Books/Computer books

%description -n %kname-doc
This package contains documentation files form the kernel source. Various
bits of information about the Linux kernel and the device drivers shipped
with it are documented in these files. You also might want install this
package if you need a reference to the options that can be passed to Linux
kernel modules at load time.

%globalwarning
%endif

#############################
# End of package definition #
#############################
%prep
%setup -q -n linux-%kversion-%usepatch

%patch1 -p1
#%patch10 -p1
#%patch20 -p1
%patch30 -p1
#%patch31 -p1
#%patch32 -p1
# Config
%setup -D -T -n linux-%kversion-%usepatch -a10

# Tagging kernel version as mdk

%build
%define temproot ../kernel-%KVERREL-root
%define tempboot %{temproot}/boot

buildkernel () {
    flavour=$1
    cp kernel-config-%level-%{_target_cpu}$flavour .config
    perl -pi -e "s/^EXTRAVERSION =.*/EXTRAVERSION = -%realrelease$flavour/" Makefile
    %make clean
    #make oldconfig
    %make all

    INSTALL_MOD_PATH=%temproot/$flavour make modules_install
    mkdir -p %tempboot/$flavour
    cp System.map %tempboot/$flavour/System.map-%KVERREL$flavour
    cp .config %tempboot/$flavour/config-%KVERREL$flavour

    %ifarch %ix86 x86_64
        cp arch/i386/boot/bzImage %{tempboot}/$flavour/vmlinuz-%{KVERREL}${flavour}
    %endif
    %ifarch ppc
        cp -f vmlinux %{tempboot}/vmlinuz-%{KVERREL}${flavour}
        cp -f arch/ppc/boot/images/zImage.chrp-rs6k %{tempboot}/vmlinuz-rs6k-%{KVERREL}${flavour}
    %endif
    %ifarch alpha
        cp -f arch/alpha/boot/vmlinux.gz %{tempboot}/vmlinuz-%{KVERREL}${flavour}
    %endif
    %ifarch sparc sparc64
        echo "Said me what to do with those fucking kernel !"
        exit 1
    %endif
}

[ -d %temproot ] && rm -fr %temproot
[ -d %tempboot ] && rm -fr %tempboot

mkdir -p %temproot
mkdir -p %tempboot

%if %build_default
    buildkernel
%endif

%if %build_smp
    buildkernel smp
%endif

%if %build_secure
    buildkernel secure
%endif

%if %build_enterprise
    buildkernel enterprise
%endif

%if %build_um
    flavour=um
    cp kernel-config-%level-%{_target_cpu}$flavour .config
    perl -pi -e "s/^EXTRAVERSION =.*/EXTRAVERSION = -%realrelease$flavour/" Makefile
    %make ARCH=um clean
    #make oldconfig
    %make ARCH=um all

    INSTALL_MOD_PATH=%temproot/$flavour make ARCH=um modules_install
    #cp arch/i386/boot/bzImage %tempboot/$flavour/vmlinuz-%KVERREL$flavour
    #cp System.map %tempboot/$flavour/System.map-%KVERREL$flavour
    #cp .config %tempboot/$flavour/config-%KVERREL$flavour
%endif
    
%if %build_source
    make clean
    cp kernel-config-%level-%{_target_cpu}$flavour .config
    perl -pi -e "s/^EXTRAVERSION =.*/EXTRAVERSION = -%{realrelease}custom/" Makefile
    yes | make oldconfig
    make clean
%endif

%install
rm -fr $RPM_BUILD_ROOT
%define temproot ../kernel-%KVERREL-root
%define tempboot %{temproot}/boot


mkdir -p $RPM_BUILD_ROOT{/boot,/lib/modules}

installkernel () {
    flavour=$1
    mkdir -p $RPM_BUILD_ROOT/lib/modules/%KVERREL$flavour
    cp -ar %temproot/$flavour/lib/modules/* $RPM_BUILD_ROOT/lib/modules/
    cp %tempboot/$flavour/vmlinuz-* $RPM_BUILD_ROOT/boot
    cp %tempboot/$flavour/System.map-%KVERREL$flavour $RPM_BUILD_ROOT/boot
    cp %tempboot/$flavour/config-%KVERREL$flavour $RPM_BUILD_ROOT/boot
}

%if %build_source
    mkdir -p $RPM_BUILD_ROOT/usr/src/linux-%KVERREL
    # This is really not good, a first step
    ( tar cf - ./ ) | ( cd $RPM_BUILD_ROOT/usr/src/linux-%KVERREL && tar xf -)
%endif

%if %build_default
    installkernel
%endif

%if %build_smp
    installkernel smp
%endif

%if %build_secure
    installkernel secure
%endif

%if %build_enterprise
    installkernel enterprise
%endif

%if %build_um
    flavour=um
    mkdir -p $RPM_BUILD_ROOT/lib/modules/%KVERREL$flavour
    mkdir -p $RPM_BUILD_ROOT/%_bindir
    cp -ar %temproot/$flavour/lib/modules/* $RPM_BUILD_ROOT/lib/modules
    cp %temproot/$flavour/vmlinuz-%KVERREL$flavour $RPM_BUILD_ROOT/%_bindir
    #cp %temproot/$flavour/System.map-%KVERREL$flavour $RPM_BUILD_ROOT/boot
    #cp %temproot/$flavour/config-%KVERREL$flavour $RPM_BUILD_ROOT/boot

%endif

%clean
echo -rf $RPM_BUILD_ROOT
%define temproot ../kernel-%KVERREL-root
%define tempboot %{temproot}/boot
[ -d %temproot ] && rm -fr %temproot
[ -d %tempboot ] && rm -fr %tempboot


# do this for upgrades...in case the old modules get removed we have
# loopback in the kernel so that mkinitrd will work.
%if %build_default
%preun -n kernel-%KVERREL
/sbin/modprobe loop 2> /dev/null > /dev/null

REMOVE=
if [ -f /etc/sysconfig/system ];then
		source /etc/sysconfig/system
		[[ "$CLASS" = "beginner" ]] && REMOVE=yes
fi
if [ -f /etc/sysconfig/installkernel ];then
		source /etc/sysconfig/installkernel
		[[ "$AUTOREMOVE" = [Yy][Ee][Ss] ]] && REMOVE=yes
		[[ "$AUTOREMOVE" = [Nn][Oo] ]] && REMOVE=
fi

BUILD=/lib/modules/%{KVERREL}/build 
if [ -L $BUILD ]; then
	rm -f $BUILD
fi

[[ -n $REMOVE ]] && /sbin/installkernel -a -R -c %{KVERREL}

exit 0
%endif

%if %build_smp
%preun -n kernel-smp-%KVERREL
/sbin/modprobe loop 2> /dev/null > /dev/null

REMOVE=
if [ -f /etc/sysconfig/system ];then
		source /etc/sysconfig/system
		[[ "$CLASS" = "beginner" ]] && REMOVE=yes
fi
if [ -f /etc/sysconfig/installkernel ];then
		source /etc/sysconfig/installkernel
		[[ "$AUTOREMOVE" = [Yy][Ee][Ss] ]] && REMOVE=yes
		[[ "$AUTOREMOVE" = [Nn][Oo] ]] && REMOVE=
fi

BUILD=/lib/modules/%{KVERREL}smp/build 
if [ -L $BUILD ]; then
	rm -f $BUILD
fi

[[ -n $REMOVE ]] && /sbin/installkernel -a -R -c %{KVERREL}smp

exit 0
%endif

%if %build_enterprise
%preun -n kernel-enterprise-%KVERREL
/sbin/modprobe loop 2> /dev/null > /dev/null

REMOVE=
if [ -f /etc/sysconfig/system ];then
		source /etc/sysconfig/system
		[[ "$CLASS" = "beginner" ]] && REMOVE=yes
fi
if [ -f /etc/sysconfig/installkernel ];then
		source /etc/sysconfig/installkernel
		[[ "$AUTOREMOVE" = [Yy][Ee][Ss] ]] && REMOVE=yes
		[[ "$AUTOREMOVE" = [Nn][Oo] ]] && REMOVE=
fi

BUILD=/lib/modules/%{KVERREL}enterprise/build 
if [ -L $BUILD ]; then
	rm -f $BUILD
fi

[[ -n $REMOVE ]] && /sbin/installkernel -a -R -c %{KVERREL}enterprise

exit 0
%endif

%if %build_BOOT
%preun -n kernel-BOOT-%KVERREL
/sbin/modprobe loop 2> /dev/null > /dev/null

REMOVE=
if [ -f /etc/sysconfig/system ];then
		source /etc/sysconfig/system
		[[ "$CLASS" = "beginner" ]] && REMOVE=yes
fi
if [ -f /etc/sysconfig/installkernel ];then
		source /etc/sysconfig/installkernel
		[[ "$AUTOREMOVE" = [Yy][Ee][Ss] ]] && REMOVE=yes
		[[ "$AUTOREMOVE" = [Nn][Oo] ]] && REMOVE=
fi

BUILD=/lib/modules/%{KVERREL}BOOT/build 
if [ -L $BUILD ]; then
	rm -f $BUILD
fi

[[ -n $REMOVE ]] && /sbin/installkernel -a -R -c %{KVERREL}BOOT

exit 0
%endif

%if %build_secure
%preun -n kernel-secure-%KVERREL
/sbin/modprobe loop 2> /dev/null > /dev/null

REMOVE=
if [ -f /etc/sysconfig/system ];then
		source /etc/sysconfig/system
		[[ "$CLASS" = "beginner" ]] && REMOVE=yes
fi
if [ -f /etc/sysconfig/installkernel ];then
		source /etc/sysconfig/installkernel
		[[ "$AUTOREMOVE" = [Yy][Ee][Ss] ]] && REMOVE=yes
		[[ "$AUTOREMOVE" = [Nn][Oo] ]] && REMOVE=
fi

BUILD=/lib/modules/%{KVERREL}secure/build 
if [ -L $BUILD ]; then
	rm -f $BUILD
fi

[[ -n $REMOVE ]] && /sbin/installkernel -a -R -c %{KVERREL}secure

exit 0
%endif

%if %build_default
%post -n kernel-%KVERREL
cd %{_bootdir}
if [ -x /sbin/installkernel ];then
	      /sbin/installkernel -a -c -L %{KVERREL}
fi

KERNEL_SOURCE=/usr/src/linux-%{KVERREL}
if [ -d $KERNEL_SOURCE ]; then
	ln -sf $KERNEL_SOURCE /lib/modules/%{KVERREL}/build 
fi

%postun -n kernel-%KVERREL
cd %{_bootdir}
if [ -f initrd-%{KVERREL}.img ];then
		rm -f initrd-%{KVERREL}.img
fi
%endif

%if %build_smp
%post -n kernel-smp-%KVERREL
cd %{_bootdir}
if [ -x /sbin/installkernel ];then
	      /sbin/installkernel -a -c -L %{KVERREL}smp
fi

KERNEL_SOURCE=/usr/src/linux-%{KVERREL}
if [ -d $KERNEL_SOURCE ]; then
	ln -sf $KERNEL_SOURCE /lib/modules/%{KVERREL}smp/build 
fi

%postun -n kernel-smp-%KVERREL
cd %{_bootdir}
if [ -f initrd-%{KVERREL}smp.img ];then
		rm -f initrd-%{KVERREL}smp.img
fi
%endif

%if %build_enterprise
%post -n kernel-enterprise-%{mdkversion}
cd %{_bootdir}
if [ -x /sbin/installkernel ];then
	      /sbin/installkernel -a -c -L %{KVERREL}enterprise
fi

KERNEL_SOURCE=/usr/src/linux-%{KVERREL}
if [ -d $KERNEL_SOURCE ]; then
	ln -sf $KERNEL_SOURCE /lib/modules/%{KVERREL}enterprise/build 
fi

%postun -n kernel-enterprise-%KVERREL
cd %{_bootdir}
if [ -f initrd-%{KVERREL}enterprise.img ];then
		rm -f initrd-%{KVERREL}enterprise.img
fi
%endif

%if %build_secure
%post -n kernel-secure-%KVERREL
cd %{_bootdir}
if [ -x /sbin/installkernel ];then
	      /sbin/installkernel -a -c -L %{KVERREL}secure
fi

KERNEL_SOURCE=/usr/src/linux-%{KVERREL}
if [ -d $KERNEL_SOURCE ]; then
	ln -sf $KERNEL_SOURCE /lib/modules/%{KVERREL}secure/build 
fi

%postun -n kernel-secure-%{mdkversion}
cd %{_bootdir}
if [ -f initrd-%{KVERREL}secure.img ];then
		rm -f initrd-%{KVERREL}secure.img
fi
%endif

%if %build_BOOT
%post -n kernel-BOOT-%KVERREL
cd %{_bootdir}
if [ -x /sbin/installkernel ];then
	      /sbin/installkernel -a -c -L %{KVERREL}BOOT
fi

KERNEL_SOURCE=/usr/src/linux-%{KVERREL}
if [ -d $KERNEL_SOURCE ]; then
	ln -sf $KERNEL_SOURCE /lib/modules/%{KVERREL}BOOT/build 
fi


%postun -n kernel-BOOT-%KVERREL
cd %{_bootdir}
if [ -f initrd-%{KVERREL}BOOT.img ];then
		rm -f initrd-%{KVERREL}BOOT.img
fi
%endif

%if %build_source
%post -n %kname-source
# at time, do nothing
cd /usr/src
rm -f linux-%level
ln -snf linux-%{KVERREL} linux-%level
/sbin/service kheader start 2>/dev/null >/dev/null || :
# we need to create /build only when there is a source tree.
for i in "" BOOT smp enterprise secure; do
	if [ -d /lib/modules/%{KVERREL}$i ]; then
		ln -sf /usr/src/linux-%{KVERREL} /lib/modules/%{KVERREL}$i/build
	fi
done


%postun -n %kname-source
# at time do nothing
if [ -L /usr/src/linux-%level ]; then 
    if [ -L /usr/src/linux-%level -a `ls -l /usr/src/linux-%level 2>/dev/null| awk '{ print $11 }'` = "linux-%{KVERREL}" ]; then
	[ $1 = 0 ] && rm -f /usr/src/linux-%level
    fi
fi
# we need to delete <modules>/build at unsinstall
for i in "" BOOT smp enterprise secure; do
	if [ -L /lib/modules/%{KVERREL}$i/build ]; then
		rm -f /lib/modules/%{KVERREL}$i/build
	fi
done
exit 0
%endif


######################
# End of post script #
######################

%if %build_default
%files -n kernel-%KVERREL
%defattr (-, root, root)
#%dir /lib/modules/%realversion-%realrelease
/lib/modules/%{KVERREL}
%_bootdir/config-%{KVERREL}
%_bootdir/vmlinuz*-%{KVERREL}
%_bootdir/System.map-%{KVERREL}
%endif

%if %build_smp
%files -n kernel-smp-%KVERREL
%defattr (-, root, root)
/lib/modules/%{KVERREL}smp
%_bootdir/config-%{KVERREL}smp
%_bootdir/vmlinuz*-%{KVERREL}smp
%_bootdir/System.map-%{KVERREL}smp
%endif

%if %build_secure
%files -n kernel-secure-%KVERREL
%defattr (-, root, root)
/lib/modules/%{KVERREL}secure
%_bootdir/config-%{KVERREL}secure
%_bootdir/vmlinuz*-%{KVERREL}secure
%_bootdir/System.map-%{KVERREL}secure
%endif

%if %build_enterprise
%files -n kernel-enterprise-%KVERREL
%defattr (-, root, root)
/lib/modules/%{KVERREL}enterprise
%_bootdir/config-%{KVERREL}entereprise
%_bootdir/vmlinuz*-%{KVERREL}entereprise
%_bootdir/System.map-%{KVERREL}entereprise
%endif

%if %build_BOOT
%files -n kernel-BOOT-%KVERREL
%defattr (-, root, root)
/lib/modules/%{KVERREL}BOOT
%_bootdir/config-%{KVERREL}BOOT
%_bootdir/vmlinuz*-%{KVERREL}BOOT
%_bootdir/System.map-%{KVERREL}BOOT
%endif

%if %build_um
%files -n kernel-um-%KVERREL
%defattr (-, root, root)
%doc root/boot/um/config-%{KVERREL}um
%_bindir/linux-%KVERREL
/lib/modules/%{KVERREL}um
%endif

%if %build_source
%files -n %kname-source
%defattr (-, root, root)
/usr/src/linux-%KVERREL
%endif

%if %build_doc
%files -n %kname-doc
%defattr (-, root, root)
%doc Documentation/
%doc COPYING MAINTAINERS CREDITS REPORTING-BUGS
%endif

%changelog

* Fri Sep 12 2003 Olivier Blin <oliv.blin@laposte.net> 2.6.0-0.test5.1mdk
- -test5
- upgrade to supermount-2.0.2-2.6.0-test5
- use O20 patch for test5
- disable RFC1483/2684 Bridged protocols (CONFIG_ATM_BR2684)
  it doesn't compile (Olivier Thauvin)

* Tue Sep 09 2003 Olivier Blin <oliv.blin@laposte.net> 2.6.0-0.test4.4mdk
- update Multimedia patch to O20 (a patch for -test4)
- supermount 2.01d (the right one for -test4)
- it does boot

* Sat Sep 06 2003 Olivier Blin <oliv.blin@laposte.net> 2.6.0-0.test4.3mdk
- require bootloader-utils instead of kernel-utils
- buildrequire db3-devel instead of libdb3.3-devel

* Tue Sep 02 2003 Olivier Blin <oliv.blin@laposte.net> 2.6.0-0.test4.2mdk
- rebuild for gcc-3.3.1-2mdk
  (Fix kernel 2.6-test4 miscompilation on IA-32)
- drop Patch32 (merged in -test3)

* Sun Aug 24 2003 Olivier Thauvin <thauvin@aerov.jussieu.fr> 2.6.0-0.test4.1mdk
- -test4

* Sun Aug 10 2003 Olivier Thauvin <thauvin@aerov.jussieu.fr> 2.6.0-0.test3.1mdk
- -test3
- update .config (Mike Benoit <ipso@snappymail.ca>)
- build smp
 
* Tue Aug 05 2003 Olivier Thauvin <thauvin@aerov.jussieu.fr> 2.6.0-0.test2.2mdk
- build network card drivers
- supermount 2.0.1a
- IDE probe patch
- config: s/i686/586/
- fix dependancy on kernel-sources

* Wed Jul 30 2003 Olivier Thauvin <thauvin@aerov.jussieu.fr> 2.6.0-0.test2.1mdk 
- 2.6.0-test2
- apply patch-test2-O10int
- make /usr/src/linux-2.6 link to permit somes build (lvm2...)
- add a version in changelog (/me sucks)
- make ppc config and build
- add requires, prereq, blabla
- include modules this times (/me resucks)
- Fi Group tag

* Fri Jul 25 2003 Olivier Thauvin <thauvin@aerov.jussieu.fr>
- First mdk spec
- TODO:
    - ports config
    - smp, secure, BOOT, um... config
    - clean up
    - test :(
    - hardware patch
- OH ! My dear Dolly...
